@@ -286,7 +286,7 @@ FT_BEGIN_HEADER
    *   options set by those programs have precedence, overwriting the value
    *   here with the configured one.
    */
-#define FT_CONFIG_OPTION_USE_HARFBUZZ
+/* #undef FT_CONFIG_OPTION_USE_HARFBUZZ */
 
 
   /**************************************************************************
